@@ -17,6 +17,7 @@ from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
     AnalysisTypeType,
+    ConfigFileStateType,
     EncryptionOptionType,
     JobStateType,
     ProviderTypeType,
@@ -198,6 +199,7 @@ CodeReviewTypeDef = TypedDict(
         "AssociationArn": str,
         "Metrics": "MetricsTypeDef",
         "AnalysisTypes": List[AnalysisTypeType],
+        "ConfigFileState": ConfigFileStateType,
     },
     total=False,
 )
@@ -555,6 +557,7 @@ MetricsSummaryTypeDef = TypedDict(
     "MetricsSummaryTypeDef",
     {
         "MeteredLinesOfCodeCount": int,
+        "SuppressedLinesOfCodeCount": int,
         "FindingsCount": int,
     },
     total=False,
@@ -564,6 +567,7 @@ MetricsTypeDef = TypedDict(
     "MetricsTypeDef",
     {
         "MeteredLinesOfCodeCount": int,
+        "SuppressedLinesOfCodeCount": int,
         "FindingsCount": int,
     },
     total=False,
